Index: runtime/vm/code_generator_ia32.cc |
=================================================================== |
--- runtime/vm/code_generator_ia32.cc (revision 778) |
+++ runtime/vm/code_generator_ia32.cc (working copy) |
@@ -1480,8 +1480,8 @@ |
ASSERT(!dst_type.IsNull()); |
ASSERT(dst_type.IsFinalized()); |
- // Any expression is assignable to the VarType. Skip the test. |
- if (dst_type.IsVarType()) { |
+ // Any expression is assignable to the DynamicType. Skip the test. |
+ if (dst_type.IsDynamicType()) { |
return; |
} |